{##
  This file contains a Jinja2 front-matter template that adds version and authorship information.
  Changing the Jinja2 templates in this file may cause incompatibility with Manubot updates.
  Pandoc automatically inserts title from metadata.yaml, so it is not included in this template.
##}

{## Uncomment & edit the following line to reference to a preprinted or published version of the manuscript. ##}
A DOI-citable version of this manuscript is available in _PLOS Computational Biology_ at <https://doi.org/10.1371/journal.pcbi.1007128>.
This version of the manuscript [contains changes](https://github.com/greenelab/meta-review/compare/b90923a99208c9152cec7929399ab1b7929cb7e2...{%- if manubot.ci_source is defined -%}{{manubot.ci_source.commit}}{%- else -%}master{%- endif -%}) subsequent to the journal publication.

{## Template to insert build date and source ##}
<small><em>
This manuscript
{% if manubot.ci_source is defined and manubot.ci_source.provider == "appveyor" -%}
([permalink]({{manubot.ci_source.artifact_url}}))
{% elif manubot.html_url_versioned is defined -%}
([permalink]({{manubot.html_url_versioned}}))
{% endif -%}
was automatically generated
{% if manubot.ci_source is defined -%}
from [{{manubot.ci_source.repo_slug}}@{{manubot.ci_source.commit | truncate(length=7, end='', leeway=0)}}](https://github.com/{{manubot.ci_source.repo_slug}}/tree/{{manubot.ci_source.commit}})
{% endif -%}
on {{manubot.date}}.
</em></small>

## Authors

{## Template for listing authors ##}
{% for author in manubot.authors %}
+ **{{author.name}}** {% if author.correspondence is defined and author.correspondence == true -%}^[✉](#correspondence)^{%- endif -%}<br>
  {%- if author.orcid is defined and author.orcid is not none %}
    ![ORCID icon](images/orcid.svg){.inline_icon}
    [{{author.orcid}}](https://orcid.org/{{author.orcid}})
  {%- endif %}
  {%- if author.github is defined and author.github is not none %}
    · ![GitHub icon](images/github.svg){.inline_icon}
    [{{author.github}}](https://github.com/{{author.github}})
  {%- endif %}
  {%- if author.twitter is defined and author.twitter is not none %}
    · ![Twitter icon](images/twitter.svg){.inline_icon}
    [{{author.twitter}}](https://twitter.com/{{author.twitter}})
  {%- endif %}<br>
  <small>
  {%- if author.affiliations is defined and author.affiliations|length %}
     {{author.affiliations | join('; ')}}
  {%- endif %}
  {%- if false and author.funders is defined and author.funders|length %}
     · Funded by {{author.funders | join('; ')}}
  {%- endif %}
  </small>
{% endfor %}

::: {#correspondence}
✉ — correspondence preferred via [GitHub Issues](https://github.com/greenelab/meta-review/issues).
Otherwise, address correspondence to <gitter@biostat.wisc.edu> and <daniel.himmelstein@gmail.com>.
:::

<!--
{## Template for listing authors with numbered affiliations according to https://github.com/greenelab/meta-review/issues/230 ##}
{% for author in manubot.authors %}
{{author.name}}^{{author.affiliation_numbers | join(',')}}{% if author.correspondence is defined and author.correspondence == true -%}[*](#correspondence){%- endif -%}^
{%- if not loop.last -%}, {%- endif -%}
{% endfor %}


{% for affiliation in manubot.affiliations %}
{{affiliation.affiliation_number}}. {{affiliation.affiliation}}
{%- endfor %}


::: {#correspondence}
\* — correspondence preferred via [GitHub Issues](https://github.com/greenelab/meta-review/issues).
Otherwise, address correspondence to <gitter@biostat.wisc.edu> and <daniel.himmelstein@gmail.com>.
:::
-->
